aboutsummaryrefslogtreecommitdiff
path: root/talk/app/webrtc/objc/public
diff options
context:
space:
mode:
authorfischman@webrtc.org <fischman@webrtc.org@4adac7df-926f-26a2-2b94-8c16560cd09d>2013-09-05 21:49:58 +0000
committerfischman@webrtc.org <fischman@webrtc.org@4adac7df-926f-26a2-2b94-8c16560cd09d>2013-09-05 21:49:58 +0000
commitc31d4d03244f15681520e65bd48fd0fa5c7821a3 (patch)
tree4aa1efb16d5ebe2860d506e987021307a699b063 /talk/app/webrtc/objc/public
parentaa3d1c8169b798c06edf74651f38fef77c695157 (diff)
downloadwebrtc-c31d4d03244f15681520e65bd48fd0fa5c7821a3.tar.gz
AppRTCDemo(iOS): prefer ISAC as audio codec
This makes audio flow well bidirectionally to an iPod Touch (5th gen). Also: - Update to new turnserver JSON style: - separate username field - multiple URLs for the same server (e.g. both UDP & TCP) - Added more explicit logging for ICE Connected since it's useful for debugging - Give focus to the input field on app launch since that's the only useful thing to have focus on, anyway. - Fix minor typos - Cleaned up trailing whitespace and hard tabs BUG=2191 R=wu@webrtc.org Review URL: https://webrtc-codereview.appspot.com/2127004 git-svn-id: http://webrtc.googlecode.com/svn/trunk@4687 4adac7df-926f-26a2-2b94-8c16560cd09d
Diffstat (limited to 'talk/app/webrtc/objc/public')
-rw-r--r--talk/app/webrtc/objc/public/RTCICEServer.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/talk/app/webrtc/objc/public/RTCICEServer.h b/talk/app/webrtc/objc/public/RTCICEServer.h
index 717d042f78..63c14efaaf 100644
--- a/talk/app/webrtc/objc/public/RTCICEServer.h
+++ b/talk/app/webrtc/objc/public/RTCICEServer.h
@@ -30,14 +30,15 @@
// RTCICEServer allows for the creation of ICEServer structs.
@interface RTCICEServer : NSObject
// The server URI.
@property(nonatomic, strong, readonly) NSURL* URI;
-
-// The server password.
+@property(nonatomic, copy, readonly) NSString* username;
@property(nonatomic, copy, readonly) NSString* password;
// Initializer for RTCICEServer taking uri and password.
-- (id)initWithURI:(NSString*)URI password:(NSString*)password;
+- (id)initWithURI:(NSString*)URI
+ username:(NSString*)username
+ password:(NSString*)password;
#ifndef DOXYGEN_SHOULD_SKIP_THIS
// Disallow init and don't add to documentation
@@ -30,14 +30,15 @@
// RTCICEServer allows for the creation of ICEServer structs.
-// The server URI.
+// The server URI, username, and password.